@@ -8,14 +8,14 @@ def _signal_to_asset(
 ) -> pd.Series:
     """
     @param df: market information including 'dt', 'C', 'A' and 'B'
-    @param signal: trading decision at the end of the datetime (>0: long, <0: short, =0: hold)
+    @param signal: trading decision at the end of the datetime (>0: long, <0: short, 0: hold)
     @param init_cash: initial cash
     @param charge_ratio: transaction cost = amount * charge ratio
     @return: asset: asset series with DatetimeIndex
     """
     if len(signal) != len(df):
         raise ValueError("signal must be the same length as df")
-    sr_signal = pd.Series(signal)
+    sr_signal = pd.Series(signal, index=df.index)
     sr_long = sr_signal[sr_signal > 0]
     sr_short = sr_signal[sr_signal < 0]
     impact_cost = (sr_long * (df["A"] - df["C"])).fillna(0) + (
@@ -25,13 +25,13 @@ def _signal_to_asset(
         (sr_long * df["A"]).fillna(0) - (sr_short * df["B"]).fillna(0)
     ) * charge_ratio
     raw_position = sr_signal.cumsum() - sr_signal
-    change = (df["C"] - df["C"].shift()).fillna(0)
+    change = (df["C"] - df["C"].shift()).fillna(0).values
     raw_return = raw_position * change
-    sr_signal.index = df["dt"]
-    return pd.Series(
+    asset = pd.Series(
         np.array(init_cash + (raw_return - impact_cost - transaction_cost).cumsum()),
         index=df["dt"],
     )
+    return asset
 
 
 class Backtester:
