@@ -1,5 +1,3 @@
-import math
-
 import numpy as np
 import pandas as pd
 
@@ -14,23 +12,26 @@ class Fitness:
 
 
 def _ann_return(useless_var, asset: pd.Series) -> float:
-    days = math.ceil((asset.index[-1] - asset.index[0]) / np.timedelta64(1, "D"))
-    return (asset.values[-1] / asset.values[0]) * int(365 / days) - 1
+    return (asset.values[-1] / asset.values[0]) ** (250 / len(asset)) - 1
 
 
 def _sharpe_ratio(close: pd.Series, asset: pd.Series, r_f: float = 0.02) -> float:
-    # signals that do not trigger trades are considered the worst signal -> sharpe = np.nan
+    # factors with no trading are considered the worst factors -> sharpe = np.nan
     close_copy = close.copy()
     close_copy.index = asset.index
-    benchmark_return = max(_ann_return(None, close_copy), r_f)
-    days = math.ceil((asset.index[-1] - asset.index[0]) / np.timedelta64(1, "D"))
-    volatility = np.std(asset / asset.shift() - 1) * (365 / days)
+    # benchmark_return = max(_ann_return(None, close_copy), r_f)
+    benchmark_return = r_f
+    volatility = np.std(asset / asset.shift() - 1) * np.sqrt(250)
     excess_return = _ann_return(None, asset) - benchmark_return
+    if excess_return / volatility > 4:
+        from matplotlib import pyplot as plt
+        plt.plot(asset)
+        plt.show()
     if excess_return > 0:
-        return excess_return / volatility if volatility > 0 else np.nan
+        return excess_return / volatility if volatility else np.nan
     else:
         # adjust sharpe: if excess return < 0, then sharpe = excess return * volatility
-        return excess_return * volatility if volatility > 0 else np.nan
+        return excess_return * volatility if volatility else np.nan
 
 
 def _mean_absolute_error(y: pd.Series, y_pred: pd.Series) -> float:
@@ -57,7 +58,7 @@ direction_accuracy = Fitness(_direction_accuracy, greater_is_better=True)
 
 
 fitness_map = {
-    "ann return": ann_return,
+    "annual return": ann_return,
     "sharpe ratio": sharpe_ratio,
     "mean absolute error": mean_absolute_error,
     "mean square error": mean_square_error,
