@@ -1,4 +1,5 @@
 import random
+from typing import Any
 
 import numpy as np
 import pandas as pd
@@ -99,7 +100,7 @@ class SymbolicRegressor:
         method_probs = np.cumsum(method_probs)
         if method_probs[-1] > 1:
             raise ValueError(
-                "sum of crossover and mutation probabilities should no more than 1.0"
+                "sum of crossover and mutation probabilities should <= 1.0"
             )
         for _ in range(self.population_size):
             parent = self.__tournament()
@@ -123,7 +124,7 @@ class SymbolicRegressor:
         self.trees = offsprings
 
     def __log(self, i: int) -> None:
-        print(f"------------Generation {i + 1}------------")
+        print(f"------------Generation {str(i + 1).rjust(2)}------------")
         print(f"best estimator: {self.best_estimator}")
         print(f"best fitness: {self.best_fitness}")
 
@@ -141,6 +142,11 @@ class SymbolicRegressor:
             if self.metric.sign * (self.best_fitness - self.stopping_criteria) > 0:
                 break
             self.__evolve()
-
-    def predict(self, X: pd.DataFrame) -> float:
+    
+    def predict(self, X: pd.DataFrame) -> Any:
         return self.best_estimator.execute(X)
+
+    def score(self, X: pd.DataFrame, y: pd.Series) -> float:
+        if self.best_estimator is None:
+            raise AttributeError("cannot call score without `self.best_estimator`")
+        return self.best_estimator.fitness(X, y)
