@@ -1,4 +1,5 @@
 import random
+from typing import Any
 from copy import deepcopy
 
 import numpy as np
@@ -222,7 +223,7 @@ class SyntaxTree:
         else:
             return random.choice(candidates)
 
-    def execute(self, X: pd.DataFrame) -> float:
+    def execute(self, X: pd.DataFrame) -> Any:
         """
         Execute the program according to X
         @param X: training data
